summaryrefslogtreecommitdiff
path: root/python/filemetadata.py
diff options
context:
space:
mode:
Diffstat (limited to 'python/filemetadata.py')
-rw-r--r--python/filemetadata.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/python/filemetadata.py b/python/filemetadata.py
index bce4301f..903a36f6 100644
--- a/python/filemetadata.py
+++ b/python/filemetadata.py
@@ -201,9 +201,9 @@ class FileMetadata(object):
return core.BNIsAnalysisChanged(self.handle)
@property
- def has_database(self):
- """Whether the FileMetadata is backed by a database (read-only)"""
- return core.BNIsBackedByDatabase(self.handle)
+ def has_database(self, binary_view_type = ""):
+ """Whether the FileMetadata is backed by a database, or if specified, a specific BinaryViewType (read-only)"""
+ return core.BNIsBackedByDatabase(self.handle, binary_view_type)
@property
def view(self):